import { useDomain } from "@/hook/useDomain";
import { Button, Space, Table } from "antd";
import { useEffect, useState } from "react";
import { columnsForStudy, columnsForSeries } from "./columns";
import { EyeOutlined } from "@ant-design/icons";
import { openOHIFViewer } from "../Upload/util";

interface DicomListProps {
  children?: JSX.Element;
}

export type DataItemType = {
  StudyDate: string;
  StudyTime: string;
  AccessionNumber: string;
  Modality: string;
  PatientName: string;
  PatientID: string;
  PatientBirthDate: string;
  PatientSex: string;
  StudyInstanceUID: string;
  SeriesInstanceUID: string;
  CharacterSet: string;
  SeriesDescription: string;
  StudyID: string;
  SeriesNumber: string | number;
  NumberSeriesRelatedInstances: string | number;
  NumberPatientRelatedInstances: string | number;
  NumberPatientRelatedSeries: string | number;
  subs: DataItemType[];
};

export const DicomList = (props: DicomListProps) => {
  const [dataSource, setDataSource] = useState<DataItemType[]>([]);
  const [tableLoading, setTableLoading] = useState(false);
  const { userDomainService } = useDomain();
  useEffect(() => {
    setTableLoading(true);
    userDomainService.findDicoms().then((result) => {
      const { data } = result;
      setDataSource(data as DataItemType[]);
      setTableLoading(false);
    });
  }, []);

  /**
   * 序列级别
   */
  const expandedRowRenderForSeries = (record: DataItemType) => {
    return (
      <Table
        rowKey="SeriesInstanceUID"
        columns={[
          ...columnsForSeries,
          {
            title: "操作",
            dataIndex: "operation",
            render: (_: any, recordSeries: DataItemType) => (
              <Space>
                <Button
                  type="primary"
                  size="small"
                  icon={<EyeOutlined />}
                  onClick={() => onViewDicom(record, recordSeries)}
                >
                  阅片
                </Button>
              </Space>
            ),
          },
        ]}
        dataSource={record.subs}
        pagination={false}
      />
    );
  };

  const onViewDicom = (record: DataItemType, recordSeries: DataItemType) => {
    const { StudyInstanceUID } = record;
    const { SeriesInstanceUID } = recordSeries;
    openOHIFViewer(StudyInstanceUID, SeriesInstanceUID);
  };

  return (
    <div>
      <Table
        dataSource={dataSource}
        columns={columnsForStudy}
        loading={tableLoading}
        expandable={{
          expandedRowRender: expandedRowRenderForSeries,
        }}
        rowKey="StudyInstanceUID"
      />
    </div>
  );
};
