import { Controller } from '@nestjs/common';
import { AppService } from './app.service';
import { EventPattern } from '@nestjs/microservices';
import { ConfigService } from '@nestjs/config';
import axios from 'axios';

const metaFormatter = (data) => {
  return {
    StudyDate: data['00080020']?.Value?.[0] ?? '',
    StudyTime: data['00080030']?.Value?.[0] ?? '',
    AccessionNumber: data['00080050']?.Value?.[0] ?? '',
    Modality: data['00080060']?.Value?.[0] ?? '',
    PatientName: (data['00100010']?.Value?.[0] as any).Alphabetic,
    PatientID: data['00100020']?.Value?.[0] ?? '',
    PatientBirthDate: data['00100030']?.Value?.[0] ?? '',
    PatientSex: data['00100040']?.Value?.[0] ?? '',
    StudyInstanceUID: data['0020000D']?.Value?.[0] ?? '',
    SeriesInstanceUID: data['0020000E']?.Value?.[0] ?? '',
    CharacterSet: data['00080005']?.Value?.[0] ?? '',
    SeriesDescription: data['0008103E']?.Value?.[0] ?? '',
    StudyID: data['00200010']?.Value?.[0] ?? '',
    SeriesNumber: data['00200011']?.Value?.[0] ?? '',
    NumberSeriesRelatedInstances: data['00201209']?.Value?.[0] ?? '',
    NumberPatientRelatedInstances: data['00201206']?.Value?.[0] ?? '',
    NumberPatientRelatedSeries: data['00201208']?.Value?.[0] ?? '',
    SliceThickness: data['00180050']?.Value?.[0] ?? '',
  };
};

@Controller()
export class AppController {
  constructor(
    private readonly appService: AppService,
    private readonly configService: ConfigService,
  ) {}

  @EventPattern({ cmd: 'dicom.find.dicom' })
  async findDicoms() {
    const pacsUrl = this.configService.get('PACS_URL');
    try {
      const { data: studyData } = await axios.get(`${pacsUrl}/studies`);
      const result = [];
      for (const study of studyData) {
        const studyItem = metaFormatter(study);
        const { data: seriesData } = await axios.get(
          `${pacsUrl}/studies/${studyItem.StudyInstanceUID}/series`,
        );
        const subs = seriesData.map((s) => metaFormatter(s));
        result.push({ ...studyItem, subs });
      }
      return { data: result };
    } catch (error) {
      throw new Error(`Failed to fetch DICOM data: ${error.message}`);
    }
  }
}
